@@ -3,7 +3,7 @@
 # @Email:  kramer@mpi-cbg.de
 # @Project: go-with-the-flow
 # @Last modified by:    Felix Kramer
-# @Last modified time: 2021-06-22T23:55:48+02:00
+# @Last modified time: 2021-06-25T17:56:04+02:00
 # @License: MIT
 
 import random as rd
@@ -74,6 +74,7 @@ class flow_circuit(circuit,object):
 
         }
 
+
     # set a certain set of boundary conditions for the given networks
     def set_source_landscape(self,mode='default',**kwargs):
 
@@ -331,7 +332,7 @@ class flow_circuit(circuit,object):
     def get_edges_data(self):
 
         de=pd.DataFrame(self.edges[['conductivity','flow_rate']])
-        de['weight']=np.power(self.edges['conductivity'].to_numpy(),0.25)
+        de['weight']=np.power(self.edges['conductivity'].to_numpy(),0.25)*self.draw_weight_scaling
 
         return de
 
@@ -340,6 +341,7 @@ class flow_circuit(circuit,object):
         E=self.get_edges_data()
         V=self.get_nodes_data()
 
+        self.set_pos()
         fig=dx.plot_networkx(   self.G, edge_list=self.list_graph_edges, node_list=self.list_graph_nodes, edge_data=E,  node_data=V )
 
         return fig
